@@ -31,14 +31,20 @@ class ModelConfig:
             only_when_child_of=None, require_authenticated_user=False, restrict_queried_fields=False,
             has_permission=None, filter_for_user=None,
             on_before_operation=None, on_after_operation=None,
-            custom_fields=None, max_depth=None):
+            custom_fields=None, max_depth=None, limit=-1):
         # pylint: disable=unused-argument # for callbacks
 
         # store raw options
         self.schema = schema
-        self.require_authenticated_user = require_authenticated_user
+        if require_authenticated_user is False:
+            self.require_authenticated_user = ()
+        elif require_authenticated_user is True:
+            self.require_authenticated_user = (Operation.CREATE, Operation.READ, Operation.UPDATE, Operation.DELETE)
+        else:
+            self.require_authenticated_user = require_authenticated_user
         self.only_when_child_of = only_when_child_of
         self.max_depth = max_depth
+        self.limit = limit
         # callbacks
         callbacks_names = ('has_permission', 'filter_for_user', 'on_before_operation', 'on_after_operation')
         self.callbacks = defaultdict(list)
@@ -143,7 +149,7 @@ class ModelConfig:
                 pass_graphql_path = True,
                 pass_graphql_selection = True,
                 pass_authenticated_user = True,
-                require_authenticated_user = self.require_authenticated_user,
+                require_authenticated_user = Operation.CREATE in self.require_authenticated_user,
             )
         # expose read methods
         if self.available_operations[Operation.READ]:
@@ -157,7 +163,7 @@ class ModelConfig:
                 pass_graphql_path = True,
                 pass_graphql_selection = True,
                 pass_authenticated_user = True,
-                require_authenticated_user = self.require_authenticated_user,
+                require_authenticated_user = Operation.READ in self.require_authenticated_user,
             )
             # fetch many instances
             self.schema.expose_query(
@@ -169,7 +175,7 @@ class ModelConfig:
                 pass_graphql_path = True,
                 pass_graphql_selection = True,
                 pass_authenticated_user = True,
-                require_authenticated_user = self.require_authenticated_user,
+                require_authenticated_user = Operation.READ in self.require_authenticated_user,
             )
         # expose UPDATE method
         if self.available_operations[Operation.UPDATE]:
@@ -189,7 +195,7 @@ class ModelConfig:
                 pass_graphql_path = True,
                 pass_graphql_selection = True,
                 pass_authenticated_user = True,
-                require_authenticated_user = self.require_authenticated_user,
+                require_authenticated_user = Operation.UPDATE in self.require_authenticated_user,
             )
         # expose delete method
         if self.available_operations[Operation.DELETE]:
@@ -203,7 +209,7 @@ class ModelConfig:
                 pass_graphql_path = True,
                 pass_graphql_selection = True,
                 pass_authenticated_user = True,
-                require_authenticated_user = self.require_authenticated_user,
+                require_authenticated_user = Operation.DELETE in self.require_authenticated_user,
             )
 
     # concatenate
